@@ -22,7 +22,7 @@ def mdk(*args, **kwargs):
     @nogpu_option
     def mdk_bash():
         backend.start(implicit=True)
-        backend.cmd('exec', '-it', '@CONTAINER@', 'bash')
+        backend.cmd('exec', '-it', '--env=TERM', '@CONTAINER@', 'bash')
 
     @cli.command(name="down")
     def mdk_down():
@@ -34,7 +34,10 @@ def mdk(*args, **kwargs):
     @click.option("--tty/--no-tty", default=True, is_flag=True)
     @click.argument("command", nargs=-1, type=click.UNPROCESSED)
     def mdk_exec(command, interactive, tty):
-        args = (['--interactive'] if interactive else []) + (['--tty'] if tty else [])
+        args = (
+            (['--interactive'] if interactive else []) +
+            (['--tty', '--env=TERM'] if tty else [])
+        )
         backend.start(implicit=True)
         backend.cmd('exec', *args, '@CONTAINER@', *command)
 
@@ -89,7 +92,7 @@ def mdk(*args, **kwargs):
     @nogpu_option
     def mdk_sh():
         backend.start(implicit=True)
-        backend.cmd('exec', '-it', '@CONTAINER@', 'sh')
+        backend.cmd('exec', '-it', '--env=TERM', '@CONTAINER@', 'sh')
 
     @cli.command(name="start")
     def mdk_start():
@@ -116,6 +119,6 @@ def mdk(*args, **kwargs):
     @nogpu_option
     def mdk_zsh():
         backend.start(implicit=True)
-        backend.cmd('exec', '-it', '@CONTAINER@', 'zsh')
+        backend.cmd('exec', '-it', '--env=TERM', '@CONTAINER@', 'zsh')
 
     cli(*args, **kwargs)
