@@ -176,18 +176,26 @@ class MdkBackend:
                 if vol_src == '.' or vol_src.startswith('./'):
                     vol_src = str(self.conf_root) + vol_src[1:]
                 opt_builder += ['-v', vol_src + ':' + vol_tgt]
-
+    
         if self.conf("shareX11", bool):
-            opt_builder += ["-v", "/tmp/.X11-unix:/tmp/.X11-unix:rw",
-                            "--device", "/dev/dri:/dev/dri",
-                            "--ipc", "host",
-                            "-e", f"DISPLAY={os.getenv('DISPLAY')}"]
+            opt_builder += [
+                "-v", "/tmp/.X11-unix:/tmp/.X11-unix:rw",
+                "--device", "/dev/dri:/dev/dri",
+                "--ipc", "host"
+            ]
+            display = os.getenv('DISPLAY')
+            if display is not None:
+                opt_builder += ["-e", f"DISPLAY={display}"]
+            xauth_file = os.getenv('XAUTHORITY', None)
+            if xauth_file is not None:
+                opt_builder += ['-v', f"{xauth_file}:/tmp/.XAuthority",
+                                "-e", "XAUTHORITY=/tmp/.XAuthority"]
 
         if self.conf("core-image", bool):
             opt_builder += ["-e", f"HOST_UID={os.getuid()}",
                             "-e", f"DOCKER_CONTAINER_NAME={self.container_name()}",
-                            "-e", f"DOCKER_CONTAINER_ROOT={self.conf_root}"]
-
+                            "-e", f"DOCKER_CONTAINER_ROOT={self.conf_root}",
+                            "-e", f"DOCKER_IMAGE_NAME={self.image_name()}"]
         for env_var in self.conf_list("environment"):
             try:
                 k, v = env_var.split('=', 1)
@@ -273,7 +281,7 @@ class MdkBackend:
                      '--name', '@CONTAINER@',
                      '--label', f'{OPTS_HASH_LABEL_KEY}={self.opts_hash()}',
                      *self.build_docker_opts(),
-                     self.conf('image', required=True),
+                     self.image_name(),
                      quiet=True)
             Log.success(f'Container {self.container_name()} successfully created.')
         else:
